@@ -178,17 +178,17 @@ CORS_HEADERS = {
 }
 
 
-@predict_blueprint.route('/', methods=['GET'], provide_automatic_options=False)
+@predict_blueprint.route('', methods=['GET'], provide_automatic_options=False)
 def help_message():
     return {'message': 'Serving 服务正常工作，可以发送 POST 请求到此地址进行推理。'}, 200, CORS_HEADERS
 
 
-@predict_blueprint.route('/', methods=['OPTIONS'], provide_automatic_options=False)
+@predict_blueprint.route('', methods=['OPTIONS'], provide_automatic_options=False)
 def request_options():
     return b'', 200, CORS_HEADERS
 
 
-@predict_blueprint.route('/', methods=['POST'], provide_automatic_options=False)
+@predict_blueprint.route('', methods=['POST'], provide_automatic_options=False)
 def model_predict():
     try:
         obj = current_app.config['OPENBAYES_SERVING_PREDICTOR_OBJECT']
@@ -224,7 +224,7 @@ def model_predict():
         state = current_app.config.get('OPENBAYES_SERVING_DEBUGGER_STATE')
         log.exception('predict 函数发生了异常，请检查代码')
         if state:
-            rv = state.collect()
+            rv = state.collect_exception()
             log.error(f'使用浏览器打开 {rv["url"]} 调试此次失败的请求')
             return {'debug_url': rv['url']}, 500, CORS_HEADERS
 
@@ -293,7 +293,7 @@ def make_app(predictor_cls):
 
     if env == 'local':
         log.info('检测到本地开发环境，开启调试模式')
-        app.register_blueprint(predict_blueprint)
+        app.register_blueprint(predict_blueprint, url_prefix='/')
         debug.install(app)
         # app = WSGILogger(app)
     elif env == 'gear':
